package data_source

import (
	"eta/eta_api/models"
	"eta/eta_api/models/data_source"
	"eta/eta_api/utils"
	"fmt"
	"github.com/rdlucklib/rdluck_tools/paging"
	"github.com/tealeg/xlsx"
	"os"
	"path/filepath"
	"time"
)

// 消费者价格指数

// ComTradeCountryList
// @Title 获取居民消费价格指数分类
// @Description 获取居民消费价格指数分类
// @Success 200 {object} []data_manage.ComTradeCountryItem
// @router /icpi/classify/list [get]
func (this *DataSourceController) IcpiClassifyList() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	sysUser := this.SysUser
	if sysUser == nil {
		br.Msg = "请登录"
		br.ErrMsg = "请登录，SysUser Is Empty"
		br.Ret = 408
		return
	}

	icpiObj := new(data_source.BaseFromIcpiIndex)
	classifyList, err := icpiObj.GetBaseFromIcpiClassifyAll()
	if err != nil {
		br.Msg = "获取分类失败"
		br.ErrMsg = "获取分类失败，Err:" + err.Error()
		return
	}
	br.Ret = 200
	br.Success = true
	br.Msg = "获取成功"
	br.Data = classifyList
}

// @Title 获取消费者价格指数数据
// @Description 获取消费者价格指数数据接口
// @Param   PageSize   query   int  true       "每页数据条数"
// @Param   CurrentIndex   query   int  true       "当前页页码，从1开始"
// @Param   BaseFromIcpiClassifyId   query   int  true       "分类id"
// @Param   KeyWord   query   string  true       "关键词"
// @Success 200 {object} data_source.BaseFromIcpiIndexView
// @router /icpi/index/data [get]
func (this *DataSourceController) IcpiData() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	sysUser := this.SysUser
	if sysUser == nil {
		br.Msg = "请登录"
		br.ErrMsg = "请登录，SysUser Is Empty"
		br.Ret = 408
		return
	}

	pageSize, _ := this.GetInt("PageSize")
	currentIndex, _ := this.GetInt("CurrentIndex")
	var startSize int

	if pageSize <= 0 {
		pageSize = utils.PageSize20
	}
	if currentIndex <= 0 {
		currentIndex = 1
	}
	startSize = utils.StartIndex(currentIndex, pageSize)

	baseFromIcpiClassifyId, _ := this.GetInt("BaseFromIcpiClassifyId")
	if baseFromIcpiClassifyId < 0 {
		br.Msg = "请选择分类"
		br.ErrMsg = "请选择分类"
		return
	}

	keyword := this.GetString("KeyWord")

	//获取指标
	var condition string
	var pars []interface{}

	if baseFromIcpiClassifyId > 0 {
		condition += ` AND base_from_icpi_classify_id=? `
		pars = append(pars, baseFromIcpiClassifyId)
	}

	if keyword != "" {
		condition += ` AND (index_code =? OR index_name LIKE ?)  `
		pars = append(pars, keyword)
		pars = append(pars, "%"+keyword+"%")
	}

	icpiObj := new(data_source.BaseFromIcpiIndex)

	icpiList, err := icpiObj.GetIcpiIndex(condition, pars)
	if err != nil {
		br.Msg = "获取数据失败"
		br.ErrMsg = "获取数据失败,Err:" + err.Error()
		return
	}
	resultList := make([]*data_source.BaseFromIcpiIndexView, 0)
	for _, v := range icpiList {
		product := new(data_source.BaseFromIcpiIndexView)
		product.BaseFromIcpiIndexId = v.BaseFromIcpiIndexId
		product.BaseFromIcpiClassifyId = v.BaseFromIcpiClassifyId
		product.IndexCode = v.IndexCode
		product.IndexName = v.IndexName
		product.Frequency = v.Frequency
		product.Unit = v.Unit
		product.ModifyTime = v.ModifyTime

		total, err := icpiObj.GetIcpiIndexDataCount(v.IndexCode)
		page := paging.GetPaging(currentIndex, pageSize, total)
		dataList, err := icpiObj.GetIcpiIndexData(v.IndexCode, startSize, pageSize)
		if err != nil {
			br.Msg = "获取数据失败"
			br.ErrMsg = "获取指标数据失败,Err:" + err.Error()
			return
		}
		if dataList == nil {
			dataList = make([]*data_source.BaseFromIcpiDataView, 0)
		}
		product.DataList = dataList
		product.Paging = page
		resultList = append(resultList, product)
	}
	br.Ret = 200
	br.Success = true
	br.Msg = "获取成功"
	br.Data = resultList
}

// ExportBaiinfoList
// @Title 导出ICPI数据
// @Description 导出ICPI数据
// @Param   BaseFromIcpiClassifyId   query   int  true       "分类id"
// @Param   KeyWord   query   string  true       "关键词"
// @Success 200  导出成功
// @router /icpi/export/icpiDataList [get]
func (this *DataSourceController) ExportIcpiDataList() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()

	sysUser := this.SysUser
	if sysUser == nil {
		br.Msg = "请重新登录"
		return
	}

	baseFromIcpiClassifyId, _ := this.GetInt("BaseFromIcpiClassifyId")
	if baseFromIcpiClassifyId < 0 {
		br.Msg = "请选择分类"
		br.ErrMsg = "请选择分类"
		return
	}

	keyword := this.GetString("KeyWord")

	//获取指标
	var condition string
	var pars []interface{}

	if baseFromIcpiClassifyId >= 0 {
		condition += ` AND base_from_icpi_classify_id=? `
		pars = append(pars, baseFromIcpiClassifyId)
	}

	if keyword != "" {
		condition += ` AND (index_code =? OR index_name LIKE ?)  `
		pars = append(pars, keyword)
		pars = append(pars, "%"+keyword+"%")
	}

	icpiObj := new(data_source.BaseFromIcpiIndex)

	icpiList, err := icpiObj.GetIcpiIndex(condition, pars)
	if err != nil {
		br.Msg = "获取数据失败"
		br.ErrMsg = "获取数据失败,Err:" + err.Error()
		return
	}

	dir, _ := os.Executable()
	exPath := filepath.Dir(dir)

	downLoadnFilePath := exPath + "/" + time.Now().Format(utils.FormatDateTimeUnSpace) + ".xlsx"
	xlsxFile := xlsx.NewFile()

	if err != nil {
		fmt.Println("新增Sheet失败", err.Error())
		return
	}
	//sheetNew.SetColWidth()
	//获取指标数据
	sheetNew, _ := xlsxFile.AddSheet("ICPI消费价格指数")
	windRow := sheetNew.AddRow()
	secNameRow := sheetNew.AddRow()
	indexCodeRow := sheetNew.AddRow()
	frequencyRow := sheetNew.AddRow()
	unitRow := sheetNew.AddRow()
	lastModifyDateRow := sheetNew.AddRow()
	//获取分类下指标最大数据量
	dataMax, err := icpiObj.GetIcpiDataMaxCount(baseFromIcpiClassifyId)
	if err != nil {
		fmt.Println("获取指标最大数据量失败", err.Error())
		return
	}
	fmt.Println("dataMax:", dataMax)
	setRowIndex := 6
	for k, sv := range icpiList {
		//获取数据
		dataList, err := icpiObj.GetIcpiIndexDataByCode(sv.IndexCode)
		if err != nil {
			br.Msg = "获取数据失败"
			br.ErrMsg = "获取数据失败,Err:" + err.Error()
			return
		}
		if len(dataList) > 0 {
			windRow.AddCell().SetValue("ICPI消费价格指数")
			secNameRow.AddCell().SetValue("指标名称")
			indexCodeRow.AddCell().SetValue("指标ID")
			frequencyRow.AddCell().SetValue("频率")
			unitRow.AddCell().SetValue("单位")
			lastModifyDateRow.AddCell().SetValue("更新时间")

			secNameRow.AddCell().SetValue(sv.IndexName)
			indexCodeRow.AddCell().SetValue(sv.IndexCode)
			frequencyRow.AddCell().SetValue(sv.Frequency)
			unitRow.AddCell().SetValue(sv.Unit)
			lastModifyDateRow.AddCell().SetValue(sv.ModifyTime)

			windRow.AddCell()
			windRow.AddCell()
			secNameRow.AddCell()
			indexCodeRow.AddCell()
			frequencyRow.AddCell()
			unitRow.AddCell()
			lastModifyDateRow.AddCell()
			min := k * 3
			sheetNew.SetColWidth(min, min, 15)

			if len(dataList) <= 0 {
				for n := 0; n < dataMax; n++ {
					rowIndex := setRowIndex + n
					row := sheetNew.Row(rowIndex)
					row.AddCell()
					row.AddCell()
					row.AddCell()
					row.AddCell()
				}
			} else {
				endRowIndex := 0
				for rk, dv := range dataList {
					rowIndex := setRowIndex + rk
					row := sheetNew.Row(rowIndex)
					displayDate, _ := time.Parse(utils.FormatDate, dv.DataTime)
					displayDateCell := row.AddCell()
					style := new(xlsx.Style)
					style.ApplyAlignment = true
					style.Alignment.WrapText = true
					displayDateCell.SetStyle(style)
					displayDateCell.SetDate(displayDate)

					row.AddCell().SetValue(dv.Value)
					row.AddCell()
					endRowIndex = rowIndex
				}
				if len(dataList) < dataMax {
					dataLen := dataMax - len(dataList)
					for n := 0; n < dataLen; n++ {
						rowIndex := (endRowIndex + 1) + n
						row := sheetNew.Row(rowIndex)
						row.AddCell()
						row.AddCell()
						row.AddCell()
						row.AddCell()
					}
				}
			}
		}
	}

	err = xlsxFile.Save(downLoadnFilePath)
	if err != nil {
		//有指标无数据时先导出一遍空表
		sheet, err := xlsxFile.AddSheet("无数据")
		if err != nil {
			br.Msg = "新增Sheet失败"
			br.ErrMsg = "新增Sheet失败,Err:" + err.Error()
			return
		}
		rowSecName := sheet.AddRow()
		celSecName := rowSecName.AddCell()
		celSecName.SetValue("")
		err = xlsxFile.Save(downLoadnFilePath)
		if err != nil {
			br.Msg = "保存文件失败"
			br.ErrMsg = "保存文件失败"
			return
		}
	}
	fileName := `ICPI消费价格指数`
	fileName += time.Now().Format(utils.FormatDateUnSpace) + `.xlsx` //文件名称
	this.Ctx.Output.Download(downLoadnFilePath, fileName)
	defer func() {
		os.Remove(downLoadnFilePath)
	}()
	br.Ret = 200
	br.Success = true
	br.Msg = "success"

}
